==> doxygen-1.9.7-1-src.tar.xz: doxygen-1.9.7/doc_internal/releases.md <==
\page pg_rel Overview of doxygen release dates

The following table gives an overview of the doxygen releases with together with the release dates.
<ul class="multicol">
<li><b>Release 1.9.7</b>&nbsp;&nbsp;&nbsp; 18-05-2022</li>
<li><b>Release 1.9.6</b>&nbsp;&nbsp;&nbsp; 27-12-2022</li>
<li><b>Release 1.9.5</b>&nbsp;&nbsp;&nbsp; 26-08-2022</li>
<li><b>Release 1.9.4</b>&nbsp;&nbsp;&nbsp; 05-05-2022</li>
<li><b>Release 1.9.3</b>&nbsp;&nbsp;&nbsp; 03-01-2022</li>
<li><b>Release 1.9.3</b>&nbsp;&nbsp;&nbsp; 31-12-2021</li>
<li><b>Release 1.9.2</b>&nbsp;&nbsp;&nbsp; 18-08-2021</li>
<li><b>Release 1.9.1</b>&nbsp;&nbsp;&nbsp; 08-01-2021</li>
<li><b>Release 1.9.0</b>&nbsp;&nbsp;&nbsp; 27-12-2020</li>
<li><hr></li>
<li><b>Release 1.8.20</b>&nbsp;&nbsp; 24-08-2020</li>
<li><b>Release 1.8.19</b>&nbsp;&nbsp; 08-08-2020</li>
<li><b>Release 1.8.18</b>&nbsp;&nbsp; 12-04-2020</li>
<li><b>Release 1.8.17</b>&nbsp;&nbsp; 27-12-2019</li>
<li><b>Release 1.8.16</b>&nbsp;&nbsp; 08-08-2019</li>
<li><b>Release 1.8.15</b>&nbsp;&nbsp; 27-12-2018</li>
<li><b>Release 1.8.14</b>&nbsp;&nbsp; 25-12-2017</li>
<li><b>Release 1.8.13</b>&nbsp;&nbsp; 29-12-2016</li>
<li><b>Release 1.8.12</b>&nbsp;&nbsp; 05-09-2016</li>
<li><b>Release 1.8.11</b>&nbsp;&nbsp; 30-12-2015</li>
<li><b>Release 1.8.10</b>&nbsp;&nbsp; 27-06-2015</li>
<li><b>Release 1.8.9.1</b>&nbsp; 04-01-2015</li>
<li><b>Release 1.8.9</b>&nbsp;&nbsp;&nbsp; 25-12-2014</li>
<li><b>Release 1.8.8</b>&nbsp;&nbsp;&nbsp; 21-08-2014</li>
<li><b>Release 1.8.7</b>&nbsp;&nbsp;&nbsp; 21-04-2014</li>
<li><b>Release 1.8.6</b>&nbsp;&nbsp;&nbsp; 24-12-2013</li>
<li><b>Release 1.8.5</b>&nbsp;&nbsp;&nbsp; 23-08-2013</li>
<li><b>Release 1.8.4</b>&nbsp;&nbsp;&nbsp; 19-05-2013</li>
<li><b>Release 1.8.3.1</b>&nbsp; 20-01-2013</li>
<li><b>Release 1.8.3</b>&nbsp;&nbsp;&nbsp; 26-12-2012</li>
<li><b>Release 1.8.2</b>&nbsp;&nbsp;&nbsp; 11-08-2012</li>
<li><b>Release 1.8.1.2</b>&nbsp; 12-07-2012</li>
<li><b>Release 1.8.1.1</b>&nbsp; 10-06-2012</li>
<li><b>Release 1.8.1</b>&nbsp;&nbsp;&nbsp; 19-05-2012</li>
<li><b>Release 1.8.0</b>&nbsp;&nbsp;&nbsp; 25-02-2012</li>
<li><hr></li>
<li><b>Release 1.7.6.1</b>&nbsp; 10-12-2011</li>
<li><b>Release 1.7.6</b>&nbsp;&nbsp;&nbsp; 03-12-2011</li>
<li><b>Release 1.7.5.1</b>&nbsp; 21-08-2011</li>
<li><b>Release 1.7.5</b>&nbsp;&nbsp;&nbsp; 14-08-2011</li>
<li><b>Release 1.7.4</b>&nbsp;&nbsp;&nbsp; 28-03-2011</li>
<li><b>Release 1.7.3</b>&nbsp;&nbsp;&nbsp; 03-01-2011</li>
<li><b>Release 1.7.2</b>&nbsp;&nbsp;&nbsp; 09-10-2010</li>
<li><b>Release 1.7.1</b>&nbsp;&nbsp;&nbsp; 25-06-2010</li>
<li><b>Release 1.7.0</b>&nbsp;&nbsp;&nbsp; 15-06-2010</li>
<li><hr></li>
<li><b>Release 1.6.3</b>&nbsp;&nbsp;&nbsp; 21-02-2010</li>
<li><b>Release 1.6.2</b>&nbsp;&nbsp;&nbsp; 30-12-2009</li>
<li><b>Release 1.6.1</b>&nbsp;&nbsp;&nbsp; 25-08-2009</li>
<li><b>Release 1.6.0</b>&nbsp;&nbsp;&nbsp; 20-08-2009</li>
<li><hr></li>
<li><b>Release 1.5.9</b>&nbsp;&nbsp;&nbsp; 30-04-2009</li>
<li><b>Release 1.5.8</b>&nbsp;&nbsp;&nbsp; 27-12-2008</li>
<li><b>Release 1.5.7.1</b>&nbsp; 05-10-2008</li>
<li><b>Release 1.5.7</b>&nbsp;&nbsp;&nbsp; 28-09-2008</li>
<li><b>Release 1.5.6</b>&nbsp;&nbsp;&nbsp; 18-05-2008</li>
<li><b>Release 1.5.5</b>&nbsp;&nbsp;&nbsp; 10-02-2008</li>
<li><b>Release 1.5.4</b>&nbsp;&nbsp;&nbsp; 27-10-2007</li>
<li><b>Release 1.5.3</b>&nbsp;&nbsp;&nbsp; 27-07-2007</li>
<li><b>Release 1.5.2</b>&nbsp;&nbsp;&nbsp; 04-04-2007</li>
<li><b>Release 1.5.1</b>&nbsp;&nbsp;&nbsp; 29-10-2006</li>
<li><b>Release 1.5.0</b>&nbsp;&nbsp;&nbsp; 16-10-2006</li>
<li><hr></li>
<li><b>Release 1.4.7</b>&nbsp;&nbsp;&nbsp; 11-06-2006</li>
<li><b>Release 1.4.6</b>&nbsp;&nbsp;&nbsp; 30-12-2005</li>
<li><b>Release 1.4.5</b>&nbsp;&nbsp;&nbsp; 04-10-2005</li>
<li><b>Release 1.4.4</b>&nbsp;&nbsp;&nbsp; 21-07-2005</li>
<li><b>Release 1.4.3</b>&nbsp;&nbsp;&nbsp; 16-05-2005</li>
<li><b>Release 1.4.2</b>&nbsp;&nbsp;&nbsp; 28-03-2005</li>
<li><b>Release 1.4.1</b>&nbsp;&nbsp;&nbsp; 11-01-2005</li>
<li><b>Release 1.4.0</b>&nbsp;&nbsp;&nbsp; 31-12-2004</li>
<li><hr></li>
<li><b>Release 1.3.9.1</b>&nbsp; 10-10-2004</li>
<li><b>Release 1.3.9</b>&nbsp;&nbsp;&nbsp; 05-10-2004</li>
<li><b>Release 1.3.8</b>&nbsp;&nbsp;&nbsp; 25-07-2004</li>
<li><b>Release 1.3.7</b>&nbsp;&nbsp;&nbsp; 07-05-2004</li>
<li><b>Release 1.3.6</b>&nbsp;&nbsp;&nbsp; 12-02-2004</li>
<li><b>Release 1.3.5</b>&nbsp;&nbsp;&nbsp; 21-11-2003</li>
<li><b>Release 1.3.4</b>&nbsp;&nbsp;&nbsp; 22-09-2003</li>
<li><b>Release 1.3.3</b>&nbsp;&nbsp;&nbsp; 25-07-2003</li>
<li><b>Release 1.3.2</b>&nbsp;&nbsp;&nbsp; 15-06-2003</li>
<li><b>Release 1.3.1</b>&nbsp;&nbsp;&nbsp; 28-05-2003</li>
<li><b>Release 1.3</b>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 12-04-2003</li>
<li><hr></li>
<li><b>Release 1.2.18</b>&nbsp;&nbsp; 18-09-2002</li>
<li><b>Release 1.2.17</b>&nbsp;&nbsp; 15-07-2002</li>
<li><b>Release 1.2.16</b>&nbsp;&nbsp; 20-05-2002</li>
<li><b>Release 1.2.15</b>&nbsp;&nbsp; 01-04-2002</li>
<li><b>Release 1.2.14</b>&nbsp;&nbsp; 18-02-2002</li>
<li><b>Release 1.2.13.1</b> 05-01-2002</li>
<li><b>Release 1.2.13</b>&nbsp;&nbsp; 29-12-2001</li>
<li><b>Release 1.2.12</b>&nbsp;&nbsp; 18-11-2001</li>
<li><b>Release 1.2.11.1</b> 07-10-2001</li>
<li><b>Release 1.2.11</b>&nbsp;&nbsp; 30-09-2001</li>
<li><b>Release 1.2.10</b>&nbsp;&nbsp; 26-08-2001</li>
<li><b>Release 1.2.9.1</b>&nbsp; 05-08-2001</li>
<li><b>Release 1.2.9</b>&nbsp;&nbsp;&nbsp; 01-08-2001</li>
<li><b>Release 1.2.8.1</b>&nbsp; 10-06-2001</li>
<li><b>Release 1.2.8</b>&nbsp;&nbsp;&nbsp; 04-06-2001</li>
<li><b>Release 1.2.7</b>&nbsp;&nbsp;&nbsp; 30-04-2001</li>
<li><b>Release 1.2.6</b>&nbsp;&nbsp;&nbsp; 11-03-2001</li>
<li><b>Release 1.2.5</b>&nbsp;&nbsp;&nbsp; 04-02-2001</li>
<li><b>Release 1.2.4</b>&nbsp;&nbsp;&nbsp; 24-12-2000</li>
<li><b>Release 1.2.3</b>&nbsp;&nbsp;&nbsp; 30-10-2000</li>
<li><b>Release 1.2.2</b>&nbsp;&nbsp;&nbsp; 24-09-2000</li>
<li><b>Release 1.2.1</b>&nbsp;&nbsp;&nbsp; 13-08-2000</li>
<li><b>Release 1.2.0</b>&nbsp;&nbsp;&nbsp; 23-07-2000</li>
<li><hr></li>
<li><b>Release 1.1.5</b>&nbsp;&nbsp;&nbsp; 03-07-2000</li>
<li><b>Release 1.1.4</b>&nbsp;&nbsp;&nbsp; 04-06-2000</li>
<li><b>Release 1.1.3</b>&nbsp;&nbsp;&nbsp; 08-05-2000</li>
<li><b>Release 1.1.2</b>&nbsp;&nbsp;&nbsp; 09-04-2000</li>
<li><b>Release 1.1.1</b>&nbsp;&nbsp;&nbsp; 12-03-2000</li>
<li><b>Release 1.1.0</b>&nbsp;&nbsp;&nbsp; 15-02-2000</li>
<li><b>Release 1.0.0</b>&nbsp;&nbsp;&nbsp; 08-02-2000</li>
</ul>
<hr>

==> doxygen-1.12.0-1-src.tar.xz: doxygen-1.12.0/doc_internal/releases.md <==
\page pg_rel Overview of doxygen release dates

The following table gives an overview of the doxygen releases together with the release dates.
<ul class="multicol">
<li><b>Release 1.12.0</b>&nbsp;&nbsp; 07-08-2024</li>
<li><b>Release 1.11.0</b>&nbsp;&nbsp; 20-05-2024</li>
<li><b>Release 1.10.0</b>&nbsp;&nbsp; 25-12-2023</li>
<li><hr></li>
<li><b>Release 1.9.8</b>&nbsp;&nbsp;&nbsp; 25-08-2023</li>
<li><b>Release 1.9.7</b>&nbsp;&nbsp;&nbsp; 18-05-2023</li>
<li><b>Release 1.9.6</b>&nbsp;&nbsp;&nbsp; 27-12-2022</li>
<li><b>Release 1.9.5</b>&nbsp;&nbsp;&nbsp; 26-08-2022</li>
<li><b>Release 1.9.4</b>&nbsp;&nbsp;&nbsp; 05-05-2022</li>
<li><b>Release 1.9.3</b>&nbsp;&nbsp;&nbsp; 03-01-2022</li>
<li><b>Release 1.9.3</b>&nbsp;&nbsp;&nbsp; 31-12-2021</li>
<li><b>Release 1.9.2</b>&nbsp;&nbsp;&nbsp; 18-08-2021</li>
<li><b>Release 1.9.1</b>&nbsp;&nbsp;&nbsp; 08-01-2021</li>
<li><b>Release 1.9.0</b>&nbsp;&nbsp;&nbsp; 27-12-2020</li>
<li><hr></li>
<li><b>Release 1.8.20</b>&nbsp;&nbsp; 24-08-2020</li>
<li><b>Release 1.8.19</b>&nbsp;&nbsp; 08-08-2020</li>
<li><b>Release 1.8.18</b>&nbsp;&nbsp; 12-04-2020</li>
<li><b>Release 1.8.17</b>&nbsp;&nbsp; 27-12-2019</li>
<li><b>Release 1.8.16</b>&nbsp;&nbsp; 08-08-2019</li>
<li><b>Release 1.8.15</b>&nbsp;&nbsp; 27-12-2018</li>
<li><b>Release 1.8.14</b>&nbsp;&nbsp; 25-12-2017</li>
<li><b>Release 1.8.13</b>&nbsp;&nbsp; 29-12-2016</li>
<li><b>Release 1.8.12</b>&nbsp;&nbsp; 05-09-2016</li>
<li><b>Release 1.8.11</b>&nbsp;&nbsp; 30-12-2015</li>
<li><b>Release 1.8.10</b>&nbsp;&nbsp; 27-06-2015</li>
<li><b>Release 1.8.9.1</b>&nbsp; 04-01-2015</li>
<li><b>Release 1.8.9</b>&nbsp;&nbsp;&nbsp; 25-12-2014</li>
<li><b>Release 1.8.8</b>&nbsp;&nbsp;&nbsp; 21-08-2014</li>
<li><b>Release 1.8.7</b>&nbsp;&nbsp;&nbsp; 21-04-2014</li>
<li><b>Release 1.8.6</b>&nbsp;&nbsp;&nbsp; 24-12-2013</li>
<li><b>Release 1.8.5</b>&nbsp;&nbsp;&nbsp; 23-08-2013</li>
<li><b>Release 1.8.4</b>&nbsp;&nbsp;&nbsp; 19-05-2013</li>
<li><b>Release 1.8.3.1</b>&nbsp; 20-01-2013</li>
<li><b>Release 1.8.3</b>&nbsp;&nbsp;&nbsp; 26-12-2012</li>
<li><b>Release 1.8.2</b>&nbsp;&nbsp;&nbsp; 11-08-2012</li>
<li><b>Release 1.8.1.2</b>&nbsp; 12-07-2012</li>
<li><b>Release 1.8.1.1</b>&nbsp; 10-06-2012</li>
<li><b>Release 1.8.1</b>&nbsp;&nbsp;&nbsp; 19-05-2012</li>
<li><b>Release 1.8.0</b>&nbsp;&nbsp;&nbsp; 25-02-2012</li>
<li><hr></li>
<li><b>Release 1.7.6.1</b>&nbsp; 10-12-2011</li>
<li><b>Release 1.7.6</b>&nbsp;&nbsp;&nbsp; 03-12-2011</li>
<li><b>Release 1.7.5.1</b>&nbsp; 21-08-2011</li>
<li><b>Release 1.7.5</b>&nbsp;&nbsp;&nbsp; 14-08-2011</li>
<li><b>Release 1.7.4</b>&nbsp;&nbsp;&nbsp; 28-03-2011</li>
<li><b>Release 1.7.3</b>&nbsp;&nbsp;&nbsp; 03-01-2011</li>
<li><b>Release 1.7.2</b>&nbsp;&nbsp;&nbsp; 09-10-2010</li>
<li><b>Release 1.7.1</b>&nbsp;&nbsp;&nbsp; 25-06-2010</li>
<li><b>Release 1.7.0</b>&nbsp;&nbsp;&nbsp; 15-06-2010</li>
<li><hr></li>
<li><b>Release 1.6.3</b>&nbsp;&nbsp;&nbsp; 21-02-2010</li>
<li><b>Release 1.6.2</b>&nbsp;&nbsp;&nbsp; 30-12-2009</li>
<li><b>Release 1.6.1</b>&nbsp;&nbsp;&nbsp; 25-08-2009</li>
<li><b>Release 1.6.0</b>&nbsp;&nbsp;&nbsp; 20-08-2009</li>
<li><hr></li>
<li><b>Release 1.5.9</b>&nbsp;&nbsp;&nbsp; 30-04-2009</li>
<li><b>Release 1.5.8</b>&nbsp;&nbsp;&nbsp; 27-12-2008</li>
<li><b>Release 1.5.7.1</b>&nbsp; 05-10-2008</li>
<li><b>Release 1.5.7</b>&nbsp;&nbsp;&nbsp; 28-09-2008</li>
<li><b>Release 1.5.6</b>&nbsp;&nbsp;&nbsp; 18-05-2008</li>
<li><b>Release 1.5.5</b>&nbsp;&nbsp;&nbsp; 10-02-2008</li>
<li><b>Release 1.5.4</b>&nbsp;&nbsp;&nbsp; 27-10-2007</li>
<li><b>Release 1.5.3</b>&nbsp;&nbsp;&nbsp; 27-07-2007</li>
<li><b>Release 1.5.2</b>&nbsp;&nbsp;&nbsp; 04-04-2007</li>
<li><b>Release 1.5.1</b>&nbsp;&nbsp;&nbsp; 29-10-2006</li>
<li><b>Release 1.5.0</b>&nbsp;&nbsp;&nbsp; 16-10-2006</li>
<li><hr></li>
<li><b>Release 1.4.7</b>&nbsp;&nbsp;&nbsp; 11-06-2006</li>
<li><b>Release 1.4.6</b>&nbsp;&nbsp;&nbsp; 30-12-2005</li>
<li><b>Release 1.4.5</b>&nbsp;&nbsp;&nbsp; 04-10-2005</li>
<li><b>Release 1.4.4</b>&nbsp;&nbsp;&nbsp; 21-07-2005</li>
<li><b>Release 1.4.3</b>&nbsp;&nbsp;&nbsp; 16-05-2005</li>
<li><b>Release 1.4.2</b>&nbsp;&nbsp;&nbsp; 28-03-2005</li>
<li><b>Release 1.4.1</b>&nbsp;&nbsp;&nbsp; 11-01-2005</li>
<li><b>Release 1.4.0</b>&nbsp;&nbsp;&nbsp; 31-12-2004</li>
<li><hr></li>
<li><b>Release 1.3.9.1</b>&nbsp; 10-10-2004</li>
<li><b>Release 1.3.9</b>&nbsp;&nbsp;&nbsp; 05-10-2004</li>
<li><b>Release 1.3.8</b>&nbsp;&nbsp;&nbsp; 25-07-2004</li>
<li><b>Release 1.3.7</b>&nbsp;&nbsp;&nbsp; 07-05-2004</li>
<li><b>Release 1.3.6</b>&nbsp;&nbsp;&nbsp; 12-02-2004</li>
<li><b>Release 1.3.5</b>&nbsp;&nbsp;&nbsp; 21-11-2003</li>
<li><b>Release 1.3.4</b>&nbsp;&nbsp;&nbsp; 22-09-2003</li>
<li><b>Release 1.3.3</b>&nbsp;&nbsp;&nbsp; 25-07-2003</li>
<li><b>Release 1.3.2</b>&nbsp;&nbsp;&nbsp; 15-06-2003</li>
<li><b>Release 1.3.1</b>&nbsp;&nbsp;&nbsp; 28-05-2003</li>
<li><b>Release 1.3</b>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; 12-04-2003</li>
<li><hr></li>
<li><b>Release 1.2.18</b>&nbsp;&nbsp; 18-09-2002</li>
<li><b>Release 1.2.17</b>&nbsp;&nbsp; 15-07-2002</li>
<li><b>Release 1.2.16</b>&nbsp;&nbsp; 20-05-2002</li>
<li><b>Release 1.2.15</b>&nbsp;&nbsp; 01-04-2002</li>
<li><b>Release 1.2.14</b>&nbsp;&nbsp; 18-02-2002</li>
<li><b>Release 1.2.13.1</b> 05-01-2002</li>
<li><b>Release 1.2.13</b>&nbsp;&nbsp; 29-12-2001</li>
<li><b>Release 1.2.12</b>&nbsp;&nbsp; 18-11-2001</li>
<li><b>Release 1.2.11.1</b> 07-10-2001</li>
<li><b>Release 1.2.11</b>&nbsp;&nbsp; 30-09-2001</li>
<li><b>Release 1.2.10</b>&nbsp;&nbsp; 26-08-2001</li>
<li><b>Release 1.2.9.1</b>&nbsp; 05-08-2001</li>
<li><b>Release 1.2.9</b>&nbsp;&nbsp;&nbsp; 01-08-2001</li>
<li><b>Release 1.2.8.1</b>&nbsp; 10-06-2001</li>
<li><b>Release 1.2.8</b>&nbsp;&nbsp;&nbsp; 04-06-2001</li>
<li><b>Release 1.2.7</b>&nbsp;&nbsp;&nbsp; 30-04-2001</li>
<li><b>Release 1.2.6</b>&nbsp;&nbsp;&nbsp; 11-03-2001</li>
<li><b>Release 1.2.5</b>&nbsp;&nbsp;&nbsp; 04-02-2001</li>
<li><b>Release 1.2.4</b>&nbsp;&nbsp;&nbsp; 24-12-2000</li>
<li><b>Release 1.2.3</b>&nbsp;&nbsp;&nbsp; 30-10-2000</li>
<li><b>Release 1.2.2</b>&nbsp;&nbsp;&nbsp; 24-09-2000</li>
<li><b>Release 1.2.1</b>&nbsp;&nbsp;&nbsp; 13-08-2000</li>
<li><b>Release 1.2.0</b>&nbsp;&nbsp;&nbsp; 23-07-2000</li>
<li><hr></li>
<li><b>Release 1.1.5</b>&nbsp;&nbsp;&nbsp; 03-07-2000</li>
<li><b>Release 1.1.4</b>&nbsp;&nbsp;&nbsp; 04-06-2000</li>
<li><b>Release 1.1.3</b>&nbsp;&nbsp;&nbsp; 08-05-2000</li>
<li><b>Release 1.1.2</b>&nbsp;&nbsp;&nbsp; 09-04-2000</li>
<li><b>Release 1.1.1</b>&nbsp;&nbsp;&nbsp; 12-03-2000</li>
<li><b>Release 1.1.0</b>&nbsp;&nbsp;&nbsp; 15-02-2000</li>
<li><b>Release 1.0.0</b>&nbsp;&nbsp;&nbsp; 08-02-2000</li>
</ul>
<hr>
